Struct BufReader
pub struct BufReader<R> { /* private fields */ }Expand description
The BufReader<R> struct adds buffering to any reader.
Implementations
impl<R> BufReader<R>
impl<R> BufReader<R>
pub fn buffer(&self) -> &[u8] ⓘ
pub fn buffer(&self) -> &[u8] ⓘ
Returns a reference to the internally buffered data.
Unlike fill_buf, this will not attempt to fill the buffer if it is empty.
pub const fn capacity(&self) -> usize
pub const fn capacity(&self) -> usize
Returns the number of bytes the internal buffer can hold at once.
pub fn into_inner(self) -> R
pub fn into_inner(self) -> R
Unwraps this BufReader<R>, returning the underlying reader.