Trait Read
pub trait Read {
// Required method
fn read(&mut self, buf: &mut [u8]) -> Result<usize, AxErrorKind>;
// Provided methods
fn read_to_end(&mut self, buf: &mut Vec<u8>) -> Result<usize, AxErrorKind> { ... }
fn read_to_string(&mut self, buf: &mut String) -> Result<usize, AxErrorKind> { ... }
fn read_exact(&mut self, buf: &mut [u8]) -> Result<(), AxErrorKind> { ... }
}Expand description
The Read trait allows for reading bytes from a source.
Required Methods
fn read(&mut self, buf: &mut [u8]) -> Result<usize, AxErrorKind>
fn read(&mut self, buf: &mut [u8]) -> Result<usize, AxErrorKind>
Pull some bytes from this source into the specified buffer, returning how many bytes were read.
Provided Methods
fn read_to_end(&mut self, buf: &mut Vec<u8>) -> Result<usize, AxErrorKind>
fn read_to_end(&mut self, buf: &mut Vec<u8>) -> Result<usize, AxErrorKind>
Read all bytes until EOF in this source, placing them into buf.
fn read_to_string(&mut self, buf: &mut String) -> Result<usize, AxErrorKind>
fn read_to_string(&mut self, buf: &mut String) -> Result<usize, AxErrorKind>
Read all bytes until EOF in this source, appending them to buf.
fn read_exact(&mut self, buf: &mut [u8]) -> Result<(), AxErrorKind>
fn read_exact(&mut self, buf: &mut [u8]) -> Result<(), AxErrorKind>
Read the exact number of bytes required to fill buf.